"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

from collections import abc as _abc
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
import builtins as _builtins
import sys
import typing as _typing

if sys.version_info >= (3, 10):
    from typing import TypeAlias as _TypeAlias
else:
    from typing_extensions import TypeAlias as _TypeAlias

DESCRIPTOR: _descriptor.FileDescriptor

@_typing.final
class PremiumMarketingComponentProperties(_message.Message):
    DESCRIPTOR: _descriptor.Descriptor

    class _ButtonAction:
        ValueType = _typing.NewType("ValueType", _builtins.int)
        V: _TypeAlias = ValueType  # noqa: Y015

    class _ButtonActionEnumTypeWrapper(_enum_type_wrapper._EnumTypeWrapper[PremiumMarketingComponentProperties._ButtonAction.ValueType], _builtins.type):
        DESCRIPTOR: _descriptor.EnumDescriptor
        BUTTON_ACTION_UNSPECIFIED: PremiumMarketingComponentProperties._ButtonAction.ValueType  # 0
        BUTTON_ACTION_OPEN_MARKETING_PAGE: PremiumMarketingComponentProperties._ButtonAction.ValueType  # 1
        BUTTON_ACTION_OPEN_TIER_2_PAYMENT_MODAL: PremiumMarketingComponentProperties._ButtonAction.ValueType  # 2
        BUTTON_ACTION_OPEN_TIER_1_PAYMENT_MODAL: PremiumMarketingComponentProperties._ButtonAction.ValueType  # 3
        BUTTON_ACTION_OPEN_TIER_2_PAYMENT_MODAL_CUSTOM_CONFIRMATION_FOOTER: PremiumMarketingComponentProperties._ButtonAction.ValueType  # 4
        BUTTON_ACTION_OPEN_PLAN_SELECTION_MODAL: PremiumMarketingComponentProperties._ButtonAction.ValueType  # 5

    class ButtonAction(_ButtonAction, metaclass=_ButtonActionEnumTypeWrapper): ...
    BUTTON_ACTION_UNSPECIFIED: PremiumMarketingComponentProperties.ButtonAction.ValueType  # 0
    BUTTON_ACTION_OPEN_MARKETING_PAGE: PremiumMarketingComponentProperties.ButtonAction.ValueType  # 1
    BUTTON_ACTION_OPEN_TIER_2_PAYMENT_MODAL: PremiumMarketingComponentProperties.ButtonAction.ValueType  # 2
    BUTTON_ACTION_OPEN_TIER_1_PAYMENT_MODAL: PremiumMarketingComponentProperties.ButtonAction.ValueType  # 3
    BUTTON_ACTION_OPEN_TIER_2_PAYMENT_MODAL_CUSTOM_CONFIRMATION_FOOTER: PremiumMarketingComponentProperties.ButtonAction.ValueType  # 4
    BUTTON_ACTION_OPEN_PLAN_SELECTION_MODAL: PremiumMarketingComponentProperties.ButtonAction.ValueType  # 5

    @_typing.final
    class FeatureCard(_message.Message):
        DESCRIPTOR: _descriptor.Descriptor

        HEADER_FIELD_NUMBER: _builtins.int
        PILL_FIELD_NUMBER: _builtins.int
        BODY_FIELD_NUMBER: _builtins.int
        IMAGE_LINK_FIELD_NUMBER: _builtins.int
        IMAGE_LINK_LIGHT_THEME_FIELD_NUMBER: _builtins.int
        header: _builtins.str
        pill: _builtins.str
        body: _builtins.str
        image_link: _builtins.str
        image_link_light_theme: _builtins.str
        def __init__(
            self,
            *,
            header: _builtins.str = ...,
            pill: _builtins.str = ...,
            body: _builtins.str = ...,
            image_link: _builtins.str = ...,
            image_link_light_theme: _builtins.str = ...,
        ) -> None: ...
        _ClearFieldArgType: _TypeAlias = _typing.Literal["body", b"body", "header", b"header", "image_link", b"image_link", "image_link_light_theme", b"image_link_light_theme", "pill", b"pill"]  # noqa: Y015
        def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

    @_typing.final
    class SubscriptionButton(_message.Message):
        DESCRIPTOR: _descriptor.Descriptor

        COPY_FIELD_NUMBER: _builtins.int
        BUTTON_ACTION_FIELD_NUMBER: _builtins.int
        copy: _builtins.str
        button_action: Global___PremiumMarketingComponentProperties.ButtonAction.ValueType
        def __init__(
            self,
            *,
            copy: _builtins.str = ...,
            button_action: Global___PremiumMarketingComponentProperties.ButtonAction.ValueType = ...,
        ) -> None: ...
        _ClearFieldArgType: _TypeAlias = _typing.Literal["button_action", b"button_action", "copy", b"copy"]  # noqa: Y015
        def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

    @_typing.final
    class Subtitle(_message.Message):
        DESCRIPTOR: _descriptor.Descriptor

        LINK_FIELD_NUMBER: _builtins.int
        LOCALE_FIELD_NUMBER: _builtins.int
        IS_DEFAULT_FIELD_NUMBER: _builtins.int
        link: _builtins.str
        locale: _builtins.str
        is_default: _builtins.bool
        def __init__(
            self,
            *,
            link: _builtins.str = ...,
            locale: _builtins.str = ...,
            is_default: _builtins.bool = ...,
        ) -> None: ...
        _ClearFieldArgType: _TypeAlias = _typing.Literal["is_default", b"is_default", "link", b"link", "locale", b"locale"]  # noqa: Y015
        def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

    @_typing.final
    class Variant1Storage(_message.Message):
        DESCRIPTOR: _descriptor.Descriptor

        @_typing.final
        class HeroArtLocalizedVideoLinksDarkThemeEntry(_message.Message):
            DESCRIPTOR: _descriptor.Descriptor

            KEY_FIELD_NUMBER: _builtins.int
            VALUE_FIELD_NUMBER: _builtins.int
            key: _builtins.str
            value: _builtins.str
            def __init__(
                self,
                *,
                key: _builtins.str = ...,
                value: _builtins.str = ...,
            ) -> None: ...
            _ClearFieldArgType: _TypeAlias = _typing.Literal["key", b"key", "value", b"value"]  # noqa: Y015
            def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

        @_typing.final
        class HeroArtLocalizedVideoLinksLightThemeEntry(_message.Message):
            DESCRIPTOR: _descriptor.Descriptor

            KEY_FIELD_NUMBER: _builtins.int
            VALUE_FIELD_NUMBER: _builtins.int
            key: _builtins.str
            value: _builtins.str
            def __init__(
                self,
                *,
                key: _builtins.str = ...,
                value: _builtins.str = ...,
            ) -> None: ...
            _ClearFieldArgType: _TypeAlias = _typing.Literal["key", b"key", "value", b"value"]  # noqa: Y015
            def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

        @_typing.final
        class HeroArtVideoSubtitleLinksEntry(_message.Message):
            DESCRIPTOR: _descriptor.Descriptor

            KEY_FIELD_NUMBER: _builtins.int
            VALUE_FIELD_NUMBER: _builtins.int
            key: _builtins.str
            value: _builtins.str
            def __init__(
                self,
                *,
                key: _builtins.str = ...,
                value: _builtins.str = ...,
            ) -> None: ...
            _ClearFieldArgType: _TypeAlias = _typing.Literal["key", b"key", "value", b"value"]  # noqa: Y015
            def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

        HERO_ART_LOCALIZED_VIDEO_LINKS_DARK_THEME_FIELD_NUMBER: _builtins.int
        HERO_ART_LOCALIZED_VIDEO_LINKS_LIGHT_THEME_FIELD_NUMBER: _builtins.int
        HERO_ART_VIDEO_SUBTITLE_LINKS_FIELD_NUMBER: _builtins.int
        @_builtins.property
        def hero_art_localized_video_links_dark_theme(self) -> _containers.ScalarMap[_builtins.str, _builtins.str]: ...
        @_builtins.property
        def hero_art_localized_video_links_light_theme(self) -> _containers.ScalarMap[_builtins.str, _builtins.str]: ...
        @_builtins.property
        def hero_art_video_subtitle_links(self) -> _containers.ScalarMap[_builtins.str, _builtins.str]: ...
        def __init__(
            self,
            *,
            hero_art_localized_video_links_dark_theme: _abc.Mapping[_builtins.str, _builtins.str] | None = ...,
            hero_art_localized_video_links_light_theme: _abc.Mapping[_builtins.str, _builtins.str] | None = ...,
            hero_art_video_subtitle_links: _abc.Mapping[_builtins.str, _builtins.str] | None = ...,
        ) -> None: ...
        _ClearFieldArgType: _TypeAlias = _typing.Literal["hero_art_localized_video_links_dark_theme", b"hero_art_localized_video_links_dark_theme", "hero_art_localized_video_links_light_theme", b"hero_art_localized_video_links_light_theme", "hero_art_video_subtitle_links", b"hero_art_video_subtitle_links"]  # noqa: Y015
        def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

    @_typing.final
    class AnnouncementModalVariant1Properties(_message.Message):
        DESCRIPTOR: _descriptor.Descriptor

        HEADER_FIELD_NUMBER: _builtins.int
        SUBHEADER_FIELD_NUMBER: _builtins.int
        VIDEO_LINK_FIELD_NUMBER: _builtins.int
        HELP_ARTICLE_ID_FIELD_NUMBER: _builtins.int
        FEATURE_CARDS_FIELD_NUMBER: _builtins.int
        BUTTON_FIELD_NUMBER: _builtins.int
        DISMISS_KEY_FIELD_NUMBER: _builtins.int
        HERO_ART_VIDEO_LINK_LIGHT_THEME_FIELD_NUMBER: _builtins.int
        HERO_ART_IMAGE_LINK_DARK_THEME_FIELD_NUMBER: _builtins.int
        HERO_ART_IMAGE_LINK_LIGHT_THEME_FIELD_NUMBER: _builtins.int
        MODAL_TOP_PILL_FIELD_NUMBER: _builtins.int
        BODY_FIELD_NUMBER: _builtins.int
        HERO_ART_VIDEO_SUBTITLES_FIELD_NUMBER: _builtins.int
        STORAGE_FIELD_NUMBER: _builtins.int
        header: _builtins.str
        subheader: _builtins.str
        video_link: _builtins.str
        help_article_id: _builtins.str
        dismiss_key: _builtins.str
        hero_art_video_link_light_theme: _builtins.str
        hero_art_image_link_dark_theme: _builtins.str
        hero_art_image_link_light_theme: _builtins.str
        modal_top_pill: _builtins.str
        body: _builtins.str
        @_builtins.property
        def feature_cards(self) -> _containers.RepeatedCompositeFieldContainer[Global___PremiumMarketingComponentProperties.FeatureCard]: ...
        @_builtins.property
        def button(self) -> Global___PremiumMarketingComponentProperties.SubscriptionButton: ...
        @_builtins.property
        def hero_art_video_subtitles(self) -> _containers.RepeatedCompositeFieldContainer[Global___PremiumMarketingComponentProperties.Subtitle]: ...
        @_builtins.property
        def storage(self) -> Global___PremiumMarketingComponentProperties.Variant1Storage: ...
        def __init__(
            self,
            *,
            header: _builtins.str = ...,
            subheader: _builtins.str = ...,
            video_link: _builtins.str = ...,
            help_article_id: _builtins.str = ...,
            feature_cards: _abc.Iterable[Global___PremiumMarketingComponentProperties.FeatureCard] | None = ...,
            button: Global___PremiumMarketingComponentProperties.SubscriptionButton | None = ...,
            dismiss_key: _builtins.str = ...,
            hero_art_video_link_light_theme: _builtins.str = ...,
            hero_art_image_link_dark_theme: _builtins.str = ...,
            hero_art_image_link_light_theme: _builtins.str = ...,
            modal_top_pill: _builtins.str = ...,
            body: _builtins.str = ...,
            hero_art_video_subtitles: _abc.Iterable[Global___PremiumMarketingComponentProperties.Subtitle] | None = ...,
            storage: Global___PremiumMarketingComponentProperties.Variant1Storage | None = ...,
        ) -> None: ...
        _HasFieldArgType: _TypeAlias = _typing.Literal["_button", b"_button", "_storage", b"_storage", "button", b"button", "storage", b"storage"]  # noqa: Y015
        def HasField(self, field_name: _HasFieldArgType) -> _builtins.bool: ...
        _ClearFieldArgType: _TypeAlias = _typing.Literal["_button", b"_button", "_storage", b"_storage", "body", b"body", "button", b"button", "dismiss_key", b"dismiss_key", "feature_cards", b"feature_cards", "header", b"header", "help_article_id", b"help_article_id", "hero_art_image_link_dark_theme", b"hero_art_image_link_dark_theme", "hero_art_image_link_light_theme", b"hero_art_image_link_light_theme", "hero_art_video_link_light_theme", b"hero_art_video_link_light_theme", "hero_art_video_subtitles", b"hero_art_video_subtitles", "modal_top_pill", b"modal_top_pill", "storage", b"storage", "subheader", b"subheader", "video_link", b"video_link"]  # noqa: Y015
        def ClearField(self, field_name: _ClearFieldArgType) -> None: ...
        _WhichOneofReturnType__button: _TypeAlias = _typing.Literal["button"]  # noqa: Y015
        _WhichOneofArgType__button: _TypeAlias = _typing.Literal["_button", b"_button"]  # noqa: Y015
        _WhichOneofReturnType__storage: _TypeAlias = _typing.Literal["storage"]  # noqa: Y015
        _WhichOneofArgType__storage: _TypeAlias = _typing.Literal["_storage", b"_storage"]  # noqa: Y015
        @_typing.overload
        def WhichOneof(self, oneof_group: _WhichOneofArgType__button) -> _WhichOneofReturnType__button | None: ...
        @_typing.overload
        def WhichOneof(self, oneof_group: _WhichOneofArgType__storage) -> _WhichOneofReturnType__storage | None: ...

    @_typing.final
    class PremiumTab(_message.Message):
        DESCRIPTOR: _descriptor.Descriptor

        BADGE_LABEL_FIELD_NUMBER: _builtins.int
        ACKNOWLEDGED_BADGE_LABEL_FIELD_NUMBER: _builtins.int
        badge_label: _builtins.str
        acknowledged_badge_label: _builtins.str
        def __init__(
            self,
            *,
            badge_label: _builtins.str = ...,
            acknowledged_badge_label: _builtins.str = ...,
        ) -> None: ...
        _ClearFieldArgType: _TypeAlias = _typing.Literal["acknowledged_badge_label", b"acknowledged_badge_label", "badge_label", b"badge_label"]  # noqa: Y015
        def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

    @_typing.final
    class MarketingPageBannerButton(_message.Message):
        DESCRIPTOR: _descriptor.Descriptor

        COPY_FIELD_NUMBER: _builtins.int
        BUTTON_ACTION_FIELD_NUMBER: _builtins.int
        copy: _builtins.str
        button_action: Global___PremiumMarketingComponentProperties.ButtonAction.ValueType
        def __init__(
            self,
            *,
            copy: _builtins.str = ...,
            button_action: Global___PremiumMarketingComponentProperties.ButtonAction.ValueType = ...,
        ) -> None: ...
        _ClearFieldArgType: _TypeAlias = _typing.Literal["button_action", b"button_action", "copy", b"copy"]  # noqa: Y015
        def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

    @_typing.final
    class MarketingPageBanner(_message.Message):
        DESCRIPTOR: _descriptor.Descriptor

        ASSET_URL_FIELD_NUMBER: _builtins.int
        HEADER_FIELD_NUMBER: _builtins.int
        BODY_FIELD_NUMBER: _builtins.int
        HELP_ARTICLE_ID_FIELD_NUMBER: _builtins.int
        BUTTON_FIELD_NUMBER: _builtins.int
        asset_url: _builtins.str
        header: _builtins.str
        body: _builtins.str
        help_article_id: _builtins.str
        @_builtins.property
        def button(self) -> Global___PremiumMarketingComponentProperties.MarketingPageBannerButton: ...
        def __init__(
            self,
            *,
            asset_url: _builtins.str = ...,
            header: _builtins.str = ...,
            body: _builtins.str = ...,
            help_article_id: _builtins.str = ...,
            button: Global___PremiumMarketingComponentProperties.MarketingPageBannerButton | None = ...,
        ) -> None: ...
        _HasFieldArgType: _TypeAlias = _typing.Literal["_button", b"_button", "button", b"button"]  # noqa: Y015
        def HasField(self, field_name: _HasFieldArgType) -> _builtins.bool: ...
        _ClearFieldArgType: _TypeAlias = _typing.Literal["_button", b"_button", "asset_url", b"asset_url", "body", b"body", "button", b"button", "header", b"header", "help_article_id", b"help_article_id"]  # noqa: Y015
        def ClearField(self, field_name: _ClearFieldArgType) -> None: ...
        _WhichOneofReturnType__button: _TypeAlias = _typing.Literal["button"]  # noqa: Y015
        _WhichOneofArgType__button: _TypeAlias = _typing.Literal["_button", b"_button"]  # noqa: Y015
        def WhichOneof(self, oneof_group: _WhichOneofArgType__button) -> _WhichOneofReturnType__button | None: ...

    @_typing.final
    class PaymentModalBanner(_message.Message):
        DESCRIPTOR: _descriptor.Descriptor

        ASSET_URL_FIELD_NUMBER: _builtins.int
        HEADER_FIELD_NUMBER: _builtins.int
        BODY_FIELD_NUMBER: _builtins.int
        asset_url: _builtins.str
        header: _builtins.str
        body: _builtins.str
        def __init__(
            self,
            *,
            asset_url: _builtins.str = ...,
            header: _builtins.str = ...,
            body: _builtins.str = ...,
        ) -> None: ...
        _ClearFieldArgType: _TypeAlias = _typing.Literal["asset_url", b"asset_url", "body", b"body", "header", b"header"]  # noqa: Y015
        def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

    @_typing.final
    class CTAButton(_message.Message):
        DESCRIPTOR: _descriptor.Descriptor

        COPY_FIELD_NUMBER: _builtins.int
        copy: _builtins.str
        def __init__(
            self,
            *,
            copy: _builtins.str = ...,
        ) -> None: ...
        _ClearFieldArgType: _TypeAlias = _typing.Literal["copy", b"copy"]  # noqa: Y015
        def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

    @_typing.final
    class MobileBottomSheet(_message.Message):
        DESCRIPTOR: _descriptor.Descriptor

        ASSET_URL_FIELD_NUMBER: _builtins.int
        HEADER_FIELD_NUMBER: _builtins.int
        BODY_FIELD_NUMBER: _builtins.int
        HELP_ARTICLE_ID_FIELD_NUMBER: _builtins.int
        BUTTON_FIELD_NUMBER: _builtins.int
        asset_url: _builtins.str
        header: _builtins.str
        body: _builtins.str
        help_article_id: _builtins.str
        @_builtins.property
        def button(self) -> Global___PremiumMarketingComponentProperties.CTAButton: ...
        def __init__(
            self,
            *,
            asset_url: _builtins.str = ...,
            header: _builtins.str = ...,
            body: _builtins.str = ...,
            help_article_id: _builtins.str = ...,
            button: Global___PremiumMarketingComponentProperties.CTAButton | None = ...,
        ) -> None: ...
        _HasFieldArgType: _TypeAlias = _typing.Literal["_button", b"_button", "button", b"button"]  # noqa: Y015
        def HasField(self, field_name: _HasFieldArgType) -> _builtins.bool: ...
        _ClearFieldArgType: _TypeAlias = _typing.Literal["_button", b"_button", "asset_url", b"asset_url", "body", b"body", "button", b"button", "header", b"header", "help_article_id", b"help_article_id"]  # noqa: Y015
        def ClearField(self, field_name: _ClearFieldArgType) -> None: ...
        _WhichOneofReturnType__button: _TypeAlias = _typing.Literal["button"]  # noqa: Y015
        _WhichOneofArgType__button: _TypeAlias = _typing.Literal["_button", b"_button"]  # noqa: Y015
        def WhichOneof(self, oneof_group: _WhichOneofArgType__button) -> _WhichOneofReturnType__button | None: ...

    @_typing.final
    class Gradient(_message.Message):
        DESCRIPTOR: _descriptor.Descriptor

        COLORS_FIELD_NUMBER: _builtins.int
        ANGLE_FIELD_NUMBER: _builtins.int
        angle: _builtins.float
        @_builtins.property
        def colors(self) -> _containers.RepeatedScalarFieldContainer[_builtins.str]: ...
        def __init__(
            self,
            *,
            colors: _abc.Iterable[_builtins.str] | None = ...,
            angle: _builtins.float = ...,
        ) -> None: ...
        _ClearFieldArgType: _TypeAlias = _typing.Literal["angle", b"angle", "colors", b"colors"]  # noqa: Y015
        def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

    @_typing.final
    class GiftIcon(_message.Message):
        DESCRIPTOR: _descriptor.Descriptor

        BOX_ANIMATION_URL_FIELD_NUMBER: _builtins.int
        TRINKET_ANIMATION_URL_FIELD_NUMBER: _builtins.int
        TRINKET_GLOW_ANIMATION_URL_FIELD_NUMBER: _builtins.int
        GRADIENT_FIELD_NUMBER: _builtins.int
        box_animation_url: _builtins.str
        trinket_animation_url: _builtins.str
        trinket_glow_animation_url: _builtins.str
        @_builtins.property
        def gradient(self) -> Global___PremiumMarketingComponentProperties.Gradient: ...
        def __init__(
            self,
            *,
            box_animation_url: _builtins.str = ...,
            trinket_animation_url: _builtins.str = ...,
            trinket_glow_animation_url: _builtins.str = ...,
            gradient: Global___PremiumMarketingComponentProperties.Gradient | None = ...,
        ) -> None: ...
        _HasFieldArgType: _TypeAlias = _typing.Literal["_gradient", b"_gradient", "gradient", b"gradient"]  # noqa: Y015
        def HasField(self, field_name: _HasFieldArgType) -> _builtins.bool: ...
        _ClearFieldArgType: _TypeAlias = _typing.Literal["_gradient", b"_gradient", "box_animation_url", b"box_animation_url", "gradient", b"gradient", "trinket_animation_url", b"trinket_animation_url", "trinket_glow_animation_url", b"trinket_glow_animation_url"]  # noqa: Y015
        def ClearField(self, field_name: _ClearFieldArgType) -> None: ...
        _WhichOneofReturnType__gradient: _TypeAlias = _typing.Literal["gradient"]  # noqa: Y015
        _WhichOneofArgType__gradient: _TypeAlias = _typing.Literal["_gradient", b"_gradient"]  # noqa: Y015
        def WhichOneof(self, oneof_group: _WhichOneofArgType__gradient) -> _WhichOneofReturnType__gradient | None: ...

    @_typing.final
    class ThemeAwareAsset(_message.Message):
        DESCRIPTOR: _descriptor.Descriptor

        LIGHT_URL_FIELD_NUMBER: _builtins.int
        DARK_URL_FIELD_NUMBER: _builtins.int
        LIGHT_STATIC_URL_FIELD_NUMBER: _builtins.int
        DARK_STATIC_URL_FIELD_NUMBER: _builtins.int
        light_url: _builtins.str
        dark_url: _builtins.str
        light_static_url: _builtins.str
        dark_static_url: _builtins.str
        def __init__(
            self,
            *,
            light_url: _builtins.str = ...,
            dark_url: _builtins.str = ...,
            light_static_url: _builtins.str = ...,
            dark_static_url: _builtins.str = ...,
        ) -> None: ...
        _ClearFieldArgType: _TypeAlias = _typing.Literal["dark_static_url", b"dark_static_url", "dark_url", b"dark_url", "light_static_url", b"light_static_url", "light_url", b"light_url"]  # noqa: Y015
        def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

    @_typing.final
    class GiftIconCoachmark(_message.Message):
        DESCRIPTOR: _descriptor.Descriptor

        HEADER_FIELD_NUMBER: _builtins.int
        BODY_FIELD_NUMBER: _builtins.int
        ASSET_URL_FIELD_NUMBER: _builtins.int
        ASSET_FIELD_NUMBER: _builtins.int
        header: _builtins.str
        body: _builtins.str
        asset_url: _builtins.str
        @_builtins.property
        def asset(self) -> Global___PremiumMarketingComponentProperties.ThemeAwareAsset: ...
        def __init__(
            self,
            *,
            header: _builtins.str = ...,
            body: _builtins.str = ...,
            asset_url: _builtins.str = ...,
            asset: Global___PremiumMarketingComponentProperties.ThemeAwareAsset | None = ...,
        ) -> None: ...
        _HasFieldArgType: _TypeAlias = _typing.Literal["_asset", b"_asset", "asset", b"asset"]  # noqa: Y015
        def HasField(self, field_name: _HasFieldArgType) -> _builtins.bool: ...
        _ClearFieldArgType: _TypeAlias = _typing.Literal["_asset", b"_asset", "asset", b"asset", "asset_url", b"asset_url", "body", b"body", "header", b"header"]  # noqa: Y015
        def ClearField(self, field_name: _ClearFieldArgType) -> None: ...
        _WhichOneofReturnType__asset: _TypeAlias = _typing.Literal["asset"]  # noqa: Y015
        _WhichOneofArgType__asset: _TypeAlias = _typing.Literal["_asset", b"_asset"]  # noqa: Y015
        def WhichOneof(self, oneof_group: _WhichOneofArgType__asset) -> _WhichOneofReturnType__asset | None: ...

    @_typing.final
    class GiftPlanSelectionCardBanner(_message.Message):
        DESCRIPTOR: _descriptor.Descriptor

        HEADER_FIELD_NUMBER: _builtins.int
        DESKTOP_BODY_FIELD_NUMBER: _builtins.int
        MOBILE_BODY_FIELD_NUMBER: _builtins.int
        AVATAR_ASSET_FIELD_NUMBER: _builtins.int
        BANNER_ASSET_URL_FIELD_NUMBER: _builtins.int
        BACKGROUND_ASSET_URL_FIELD_NUMBER: _builtins.int
        CARD_ASSET_URL_FIELD_NUMBER: _builtins.int
        GRADIENT_FIELD_NUMBER: _builtins.int
        BANNER_ASSET_FIELD_NUMBER: _builtins.int
        BACKGROUND_ASSET_FIELD_NUMBER: _builtins.int
        CARD_ASSET_FIELD_NUMBER: _builtins.int
        MOBILE_BANNER_ASSET_FIELD_NUMBER: _builtins.int
        header: _builtins.str
        desktop_body: _builtins.str
        mobile_body: _builtins.str
        banner_asset_url: _builtins.str
        background_asset_url: _builtins.str
        card_asset_url: _builtins.str
        @_builtins.property
        def avatar_asset(self) -> Global___PremiumMarketingComponentProperties.ThemeAwareAsset: ...
        @_builtins.property
        def gradient(self) -> Global___PremiumMarketingComponentProperties.Gradient: ...
        @_builtins.property
        def banner_asset(self) -> Global___PremiumMarketingComponentProperties.ThemeAwareAsset: ...
        @_builtins.property
        def background_asset(self) -> Global___PremiumMarketingComponentProperties.ThemeAwareAsset: ...
        @_builtins.property
        def card_asset(self) -> Global___PremiumMarketingComponentProperties.ThemeAwareAsset: ...
        @_builtins.property
        def mobile_banner_asset(self) -> Global___PremiumMarketingComponentProperties.ThemeAwareAsset: ...
        def __init__(
            self,
            *,
            header: _builtins.str = ...,
            desktop_body: _builtins.str = ...,
            mobile_body: _builtins.str = ...,
            avatar_asset: Global___PremiumMarketingComponentProperties.ThemeAwareAsset | None = ...,
            banner_asset_url: _builtins.str = ...,
            background_asset_url: _builtins.str = ...,
            card_asset_url: _builtins.str = ...,
            gradient: Global___PremiumMarketingComponentProperties.Gradient | None = ...,
            banner_asset: Global___PremiumMarketingComponentProperties.ThemeAwareAsset | None = ...,
            background_asset: Global___PremiumMarketingComponentProperties.ThemeAwareAsset | None = ...,
            card_asset: Global___PremiumMarketingComponentProperties.ThemeAwareAsset | None = ...,
            mobile_banner_asset: Global___PremiumMarketingComponentProperties.ThemeAwareAsset | None = ...,
        ) -> None: ...
        _HasFieldArgType: _TypeAlias = _typing.Literal["_avatar_asset", b"_avatar_asset", "_background_asset", b"_background_asset", "_banner_asset", b"_banner_asset", "_card_asset", b"_card_asset", "_gradient", b"_gradient", "_mobile_banner_asset", b"_mobile_banner_asset", "avatar_asset", b"avatar_asset", "background_asset", b"background_asset", "banner_asset", b"banner_asset", "card_asset", b"card_asset", "gradient", b"gradient", "mobile_banner_asset", b"mobile_banner_asset"]  # noqa: Y015
        def HasField(self, field_name: _HasFieldArgType) -> _builtins.bool: ...
        _ClearFieldArgType: _TypeAlias = _typing.Literal["_avatar_asset", b"_avatar_asset", "_background_asset", b"_background_asset", "_banner_asset", b"_banner_asset", "_card_asset", b"_card_asset", "_gradient", b"_gradient", "_mobile_banner_asset", b"_mobile_banner_asset", "avatar_asset", b"avatar_asset", "background_asset", b"background_asset", "background_asset_url", b"background_asset_url", "banner_asset", b"banner_asset", "banner_asset_url", b"banner_asset_url", "card_asset", b"card_asset", "card_asset_url", b"card_asset_url", "desktop_body", b"desktop_body", "gradient", b"gradient", "header", b"header", "mobile_banner_asset", b"mobile_banner_asset", "mobile_body", b"mobile_body"]  # noqa: Y015
        def ClearField(self, field_name: _ClearFieldArgType) -> None: ...
        _WhichOneofReturnType__avatar_asset: _TypeAlias = _typing.Literal["avatar_asset"]  # noqa: Y015
        _WhichOneofArgType__avatar_asset: _TypeAlias = _typing.Literal["_avatar_asset", b"_avatar_asset"]  # noqa: Y015
        _WhichOneofReturnType__background_asset: _TypeAlias = _typing.Literal["background_asset"]  # noqa: Y015
        _WhichOneofArgType__background_asset: _TypeAlias = _typing.Literal["_background_asset", b"_background_asset"]  # noqa: Y015
        _WhichOneofReturnType__banner_asset: _TypeAlias = _typing.Literal["banner_asset"]  # noqa: Y015
        _WhichOneofArgType__banner_asset: _TypeAlias = _typing.Literal["_banner_asset", b"_banner_asset"]  # noqa: Y015
        _WhichOneofReturnType__card_asset: _TypeAlias = _typing.Literal["card_asset"]  # noqa: Y015
        _WhichOneofArgType__card_asset: _TypeAlias = _typing.Literal["_card_asset", b"_card_asset"]  # noqa: Y015
        _WhichOneofReturnType__gradient: _TypeAlias = _typing.Literal["gradient"]  # noqa: Y015
        _WhichOneofArgType__gradient: _TypeAlias = _typing.Literal["_gradient", b"_gradient"]  # noqa: Y015
        _WhichOneofReturnType__mobile_banner_asset: _TypeAlias = _typing.Literal["mobile_banner_asset"]  # noqa: Y015
        _WhichOneofArgType__mobile_banner_asset: _TypeAlias = _typing.Literal["_mobile_banner_asset", b"_mobile_banner_asset"]  # noqa: Y015
        @_typing.overload
        def WhichOneof(self, oneof_group: _WhichOneofArgType__avatar_asset) -> _WhichOneofReturnType__avatar_asset | None: ...
        @_typing.overload
        def WhichOneof(self, oneof_group: _WhichOneofArgType__background_asset) -> _WhichOneofReturnType__background_asset | None: ...
        @_typing.overload
        def WhichOneof(self, oneof_group: _WhichOneofArgType__banner_asset) -> _WhichOneofReturnType__banner_asset | None: ...
        @_typing.overload
        def WhichOneof(self, oneof_group: _WhichOneofArgType__card_asset) -> _WhichOneofReturnType__card_asset | None: ...
        @_typing.overload
        def WhichOneof(self, oneof_group: _WhichOneofArgType__gradient) -> _WhichOneofReturnType__gradient | None: ...
        @_typing.overload
        def WhichOneof(self, oneof_group: _WhichOneofArgType__mobile_banner_asset) -> _WhichOneofReturnType__mobile_banner_asset | None: ...

    @_typing.final
    class GiftCustomizationBanner(_message.Message):
        DESCRIPTOR: _descriptor.Descriptor

        ASSET_URL_FIELD_NUMBER: _builtins.int
        DESKTOP_BODY_FIELD_NUMBER: _builtins.int
        MOBILE_BODY_FIELD_NUMBER: _builtins.int
        GRADIENT_FIELD_NUMBER: _builtins.int
        BACKGROUND_ASSET_URL_FIELD_NUMBER: _builtins.int
        ASSET_FIELD_NUMBER: _builtins.int
        BACKGROUND_ASSET_FIELD_NUMBER: _builtins.int
        MOBILE_BACKGROUND_ASSET_FIELD_NUMBER: _builtins.int
        asset_url: _builtins.str
        desktop_body: _builtins.str
        mobile_body: _builtins.str
        background_asset_url: _builtins.str
        @_builtins.property
        def gradient(self) -> Global___PremiumMarketingComponentProperties.Gradient: ...
        @_builtins.property
        def asset(self) -> Global___PremiumMarketingComponentProperties.ThemeAwareAsset: ...
        @_builtins.property
        def background_asset(self) -> Global___PremiumMarketingComponentProperties.ThemeAwareAsset: ...
        @_builtins.property
        def mobile_background_asset(self) -> Global___PremiumMarketingComponentProperties.ThemeAwareAsset: ...
        def __init__(
            self,
            *,
            asset_url: _builtins.str = ...,
            desktop_body: _builtins.str = ...,
            mobile_body: _builtins.str = ...,
            gradient: Global___PremiumMarketingComponentProperties.Gradient | None = ...,
            background_asset_url: _builtins.str = ...,
            asset: Global___PremiumMarketingComponentProperties.ThemeAwareAsset | None = ...,
            background_asset: Global___PremiumMarketingComponentProperties.ThemeAwareAsset | None = ...,
            mobile_background_asset: Global___PremiumMarketingComponentProperties.ThemeAwareAsset | None = ...,
        ) -> None: ...
        _HasFieldArgType: _TypeAlias = _typing.Literal["_asset", b"_asset", "_background_asset", b"_background_asset", "_gradient", b"_gradient", "_mobile_background_asset", b"_mobile_background_asset", "asset", b"asset", "background_asset", b"background_asset", "gradient", b"gradient", "mobile_background_asset", b"mobile_background_asset"]  # noqa: Y015
        def HasField(self, field_name: _HasFieldArgType) -> _builtins.bool: ...
        _ClearFieldArgType: _TypeAlias = _typing.Literal["_asset", b"_asset", "_background_asset", b"_background_asset", "_gradient", b"_gradient", "_mobile_background_asset", b"_mobile_background_asset", "asset", b"asset", "asset_url", b"asset_url", "background_asset", b"background_asset", "background_asset_url", b"background_asset_url", "desktop_body", b"desktop_body", "gradient", b"gradient", "mobile_background_asset", b"mobile_background_asset", "mobile_body", b"mobile_body"]  # noqa: Y015
        def ClearField(self, field_name: _ClearFieldArgType) -> None: ...
        _WhichOneofReturnType__asset: _TypeAlias = _typing.Literal["asset"]  # noqa: Y015
        _WhichOneofArgType__asset: _TypeAlias = _typing.Literal["_asset", b"_asset"]  # noqa: Y015
        _WhichOneofReturnType__background_asset: _TypeAlias = _typing.Literal["background_asset"]  # noqa: Y015
        _WhichOneofArgType__background_asset: _TypeAlias = _typing.Literal["_background_asset", b"_background_asset"]  # noqa: Y015
        _WhichOneofReturnType__gradient: _TypeAlias = _typing.Literal["gradient"]  # noqa: Y015
        _WhichOneofArgType__gradient: _TypeAlias = _typing.Literal["_gradient", b"_gradient"]  # noqa: Y015
        _WhichOneofReturnType__mobile_background_asset: _TypeAlias = _typing.Literal["mobile_background_asset"]  # noqa: Y015
        _WhichOneofArgType__mobile_background_asset: _TypeAlias = _typing.Literal["_mobile_background_asset", b"_mobile_background_asset"]  # noqa: Y015
        @_typing.overload
        def WhichOneof(self, oneof_group: _WhichOneofArgType__asset) -> _WhichOneofReturnType__asset | None: ...
        @_typing.overload
        def WhichOneof(self, oneof_group: _WhichOneofArgType__background_asset) -> _WhichOneofReturnType__background_asset | None: ...
        @_typing.overload
        def WhichOneof(self, oneof_group: _WhichOneofArgType__gradient) -> _WhichOneofReturnType__gradient | None: ...
        @_typing.overload
        def WhichOneof(self, oneof_group: _WhichOneofArgType__mobile_background_asset) -> _WhichOneofReturnType__mobile_background_asset | None: ...

    @_typing.final
    class BillingSettingsNitroGiftBanner(_message.Message):
        DESCRIPTOR: _descriptor.Descriptor

        ASSET_URL_FIELD_NUMBER: _builtins.int
        HEADER_FIELD_NUMBER: _builtins.int
        BODY_FIELD_NUMBER: _builtins.int
        BACKGROUND_ASSET_URL_FIELD_NUMBER: _builtins.int
        GRADIENT_FIELD_NUMBER: _builtins.int
        TEXT_COLOR_FIELD_NUMBER: _builtins.int
        ADDITIONAL_TERMS_FIELD_NUMBER: _builtins.int
        ASSET_FIELD_NUMBER: _builtins.int
        BACKGROUND_ASSET_FIELD_NUMBER: _builtins.int
        asset_url: _builtins.str
        header: _builtins.str
        body: _builtins.str
        background_asset_url: _builtins.str
        text_color: _builtins.str
        additional_terms: _builtins.str
        @_builtins.property
        def gradient(self) -> Global___PremiumMarketingComponentProperties.Gradient: ...
        @_builtins.property
        def asset(self) -> Global___PremiumMarketingComponentProperties.ThemeAwareAsset: ...
        @_builtins.property
        def background_asset(self) -> Global___PremiumMarketingComponentProperties.ThemeAwareAsset: ...
        def __init__(
            self,
            *,
            asset_url: _builtins.str = ...,
            header: _builtins.str = ...,
            body: _builtins.str = ...,
            background_asset_url: _builtins.str = ...,
            gradient: Global___PremiumMarketingComponentProperties.Gradient | None = ...,
            text_color: _builtins.str = ...,
            additional_terms: _builtins.str = ...,
            asset: Global___PremiumMarketingComponentProperties.ThemeAwareAsset | None = ...,
            background_asset: Global___PremiumMarketingComponentProperties.ThemeAwareAsset | None = ...,
        ) -> None: ...
        _HasFieldArgType: _TypeAlias = _typing.Literal["_asset", b"_asset", "_background_asset", b"_background_asset", "_gradient", b"_gradient", "asset", b"asset", "background_asset", b"background_asset", "gradient", b"gradient"]  # noqa: Y015
        def HasField(self, field_name: _HasFieldArgType) -> _builtins.bool: ...
        _ClearFieldArgType: _TypeAlias = _typing.Literal["_asset", b"_asset", "_background_asset", b"_background_asset", "_gradient", b"_gradient", "additional_terms", b"additional_terms", "asset", b"asset", "asset_url", b"asset_url", "background_asset", b"background_asset", "background_asset_url", b"background_asset_url", "body", b"body", "gradient", b"gradient", "header", b"header", "text_color", b"text_color"]  # noqa: Y015
        def ClearField(self, field_name: _ClearFieldArgType) -> None: ...
        _WhichOneofReturnType__asset: _TypeAlias = _typing.Literal["asset"]  # noqa: Y015
        _WhichOneofArgType__asset: _TypeAlias = _typing.Literal["_asset", b"_asset"]  # noqa: Y015
        _WhichOneofReturnType__background_asset: _TypeAlias = _typing.Literal["background_asset"]  # noqa: Y015
        _WhichOneofArgType__background_asset: _TypeAlias = _typing.Literal["_background_asset", b"_background_asset"]  # noqa: Y015
        _WhichOneofReturnType__gradient: _TypeAlias = _typing.Literal["gradient"]  # noqa: Y015
        _WhichOneofArgType__gradient: _TypeAlias = _typing.Literal["_gradient", b"_gradient"]  # noqa: Y015
        @_typing.overload
        def WhichOneof(self, oneof_group: _WhichOneofArgType__asset) -> _WhichOneofReturnType__asset | None: ...
        @_typing.overload
        def WhichOneof(self, oneof_group: _WhichOneofArgType__background_asset) -> _WhichOneofReturnType__background_asset | None: ...
        @_typing.overload
        def WhichOneof(self, oneof_group: _WhichOneofArgType__gradient) -> _WhichOneofReturnType__gradient | None: ...

    @_typing.final
    class GiftReminderNagbar(_message.Message):
        DESCRIPTOR: _descriptor.Descriptor

        BODY_FIELD_NUMBER: _builtins.int
        body: _builtins.str
        def __init__(
            self,
            *,
            body: _builtins.str = ...,
        ) -> None: ...
        _ClearFieldArgType: _TypeAlias = _typing.Literal["body", b"body"]  # noqa: Y015
        def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

    @_typing.final
    class GiftReminderCoachmark(_message.Message):
        DESCRIPTOR: _descriptor.Descriptor

        HEADER_FIELD_NUMBER: _builtins.int
        BODY_FIELD_NUMBER: _builtins.int
        ASSET_URL_FIELD_NUMBER: _builtins.int
        ASSET_FIELD_NUMBER: _builtins.int
        header: _builtins.str
        body: _builtins.str
        asset_url: _builtins.str
        @_builtins.property
        def asset(self) -> Global___PremiumMarketingComponentProperties.ThemeAwareAsset: ...
        def __init__(
            self,
            *,
            header: _builtins.str = ...,
            body: _builtins.str = ...,
            asset_url: _builtins.str = ...,
            asset: Global___PremiumMarketingComponentProperties.ThemeAwareAsset | None = ...,
        ) -> None: ...
        _HasFieldArgType: _TypeAlias = _typing.Literal["_asset", b"_asset", "asset", b"asset"]  # noqa: Y015
        def HasField(self, field_name: _HasFieldArgType) -> _builtins.bool: ...
        _ClearFieldArgType: _TypeAlias = _typing.Literal["_asset", b"_asset", "asset", b"asset", "asset_url", b"asset_url", "body", b"body", "header", b"header"]  # noqa: Y015
        def ClearField(self, field_name: _ClearFieldArgType) -> None: ...
        _WhichOneofReturnType__asset: _TypeAlias = _typing.Literal["asset"]  # noqa: Y015
        _WhichOneofArgType__asset: _TypeAlias = _typing.Literal["_asset", b"_asset"]  # noqa: Y015
        def WhichOneof(self, oneof_group: _WhichOneofArgType__asset) -> _WhichOneofReturnType__asset | None: ...

    @_typing.final
    class PremiumTabTooltip(_message.Message):
        DESCRIPTOR: _descriptor.Descriptor

        HEADER_FIELD_NUMBER: _builtins.int
        BODY_FIELD_NUMBER: _builtins.int
        ASSET_FIELD_NUMBER: _builtins.int
        header: _builtins.str
        body: _builtins.str
        @_builtins.property
        def asset(self) -> Global___PremiumMarketingComponentProperties.ThemeAwareAsset: ...
        def __init__(
            self,
            *,
            header: _builtins.str = ...,
            body: _builtins.str = ...,
            asset: Global___PremiumMarketingComponentProperties.ThemeAwareAsset | None = ...,
        ) -> None: ...
        _HasFieldArgType: _TypeAlias = _typing.Literal["_asset", b"_asset", "asset", b"asset"]  # noqa: Y015
        def HasField(self, field_name: _HasFieldArgType) -> _builtins.bool: ...
        _ClearFieldArgType: _TypeAlias = _typing.Literal["_asset", b"_asset", "asset", b"asset", "body", b"body", "header", b"header"]  # noqa: Y015
        def ClearField(self, field_name: _ClearFieldArgType) -> None: ...
        _WhichOneofReturnType__asset: _TypeAlias = _typing.Literal["asset"]  # noqa: Y015
        _WhichOneofArgType__asset: _TypeAlias = _typing.Literal["_asset", b"_asset"]  # noqa: Y015
        def WhichOneof(self, oneof_group: _WhichOneofArgType__asset) -> _WhichOneofReturnType__asset | None: ...

    CONTENT_IDENTIFIER_FIELD_NUMBER: _builtins.int
    PLACEHOLDER_FIELD_NUMBER: _builtins.int
    ANNOUNCEMENT_MODAL_VARIANT_1_FIELD_NUMBER: _builtins.int
    PREMIUM_TAB_FIELD_NUMBER: _builtins.int
    MARKETING_PAGE_BANNER_FIELD_NUMBER: _builtins.int
    PAYMENT_MODAL_BANNER_FIELD_NUMBER: _builtins.int
    MOBILE_BOTTOM_SHEET_FIELD_NUMBER: _builtins.int
    GIFT_ICON_FIELD_NUMBER: _builtins.int
    GIFT_ICON_COACHMARK_FIELD_NUMBER: _builtins.int
    GIFT_PLAN_SELECTION_CARD_BANNER_FIELD_NUMBER: _builtins.int
    GIFT_CUSTOMIZATION_BANNER_FIELD_NUMBER: _builtins.int
    BILLING_SETTINGS_NITRO_GIFT_BANNER_FIELD_NUMBER: _builtins.int
    GIFT_REMINDER_NAGBAR_FIELD_NUMBER: _builtins.int
    GIFT_REMINDER_COACHMARK_FIELD_NUMBER: _builtins.int
    PREMIUM_TAB_TOOLTIP_FIELD_NUMBER: _builtins.int
    content_identifier: _builtins.str
    placeholder: _builtins.str
    @_builtins.property
    def announcement_modal_variant_1(self) -> Global___PremiumMarketingComponentProperties.AnnouncementModalVariant1Properties: ...
    @_builtins.property
    def premium_tab(self) -> Global___PremiumMarketingComponentProperties.PremiumTab: ...
    @_builtins.property
    def marketing_page_banner(self) -> Global___PremiumMarketingComponentProperties.MarketingPageBanner: ...
    @_builtins.property
    def payment_modal_banner(self) -> Global___PremiumMarketingComponentProperties.PaymentModalBanner: ...
    @_builtins.property
    def mobile_bottom_sheet(self) -> Global___PremiumMarketingComponentProperties.MobileBottomSheet: ...
    @_builtins.property
    def gift_icon(self) -> Global___PremiumMarketingComponentProperties.GiftIcon: ...
    @_builtins.property
    def gift_icon_coachmark(self) -> Global___PremiumMarketingComponentProperties.GiftIconCoachmark: ...
    @_builtins.property
    def gift_plan_selection_card_banner(self) -> Global___PremiumMarketingComponentProperties.GiftPlanSelectionCardBanner: ...
    @_builtins.property
    def gift_customization_banner(self) -> Global___PremiumMarketingComponentProperties.GiftCustomizationBanner: ...
    @_builtins.property
    def billing_settings_nitro_gift_banner(self) -> Global___PremiumMarketingComponentProperties.BillingSettingsNitroGiftBanner: ...
    @_builtins.property
    def gift_reminder_nagbar(self) -> Global___PremiumMarketingComponentProperties.GiftReminderNagbar: ...
    @_builtins.property
    def gift_reminder_coachmark(self) -> Global___PremiumMarketingComponentProperties.GiftReminderCoachmark: ...
    @_builtins.property
    def premium_tab_tooltip(self) -> Global___PremiumMarketingComponentProperties.PremiumTabTooltip: ...
    def __init__(
        self,
        *,
        content_identifier: _builtins.str = ...,
        placeholder: _builtins.str = ...,
        announcement_modal_variant_1: Global___PremiumMarketingComponentProperties.AnnouncementModalVariant1Properties | None = ...,
        premium_tab: Global___PremiumMarketingComponentProperties.PremiumTab | None = ...,
        marketing_page_banner: Global___PremiumMarketingComponentProperties.MarketingPageBanner | None = ...,
        payment_modal_banner: Global___PremiumMarketingComponentProperties.PaymentModalBanner | None = ...,
        mobile_bottom_sheet: Global___PremiumMarketingComponentProperties.MobileBottomSheet | None = ...,
        gift_icon: Global___PremiumMarketingComponentProperties.GiftIcon | None = ...,
        gift_icon_coachmark: Global___PremiumMarketingComponentProperties.GiftIconCoachmark | None = ...,
        gift_plan_selection_card_banner: Global___PremiumMarketingComponentProperties.GiftPlanSelectionCardBanner | None = ...,
        gift_customization_banner: Global___PremiumMarketingComponentProperties.GiftCustomizationBanner | None = ...,
        billing_settings_nitro_gift_banner: Global___PremiumMarketingComponentProperties.BillingSettingsNitroGiftBanner | None = ...,
        gift_reminder_nagbar: Global___PremiumMarketingComponentProperties.GiftReminderNagbar | None = ...,
        gift_reminder_coachmark: Global___PremiumMarketingComponentProperties.GiftReminderCoachmark | None = ...,
        premium_tab_tooltip: Global___PremiumMarketingComponentProperties.PremiumTabTooltip | None = ...,
    ) -> None: ...
    _HasFieldArgType: _TypeAlias = _typing.Literal["announcement_modal_variant_1", b"announcement_modal_variant_1", "billing_settings_nitro_gift_banner", b"billing_settings_nitro_gift_banner", "gift_customization_banner", b"gift_customization_banner", "gift_icon", b"gift_icon", "gift_icon_coachmark", b"gift_icon_coachmark", "gift_plan_selection_card_banner", b"gift_plan_selection_card_banner", "gift_reminder_coachmark", b"gift_reminder_coachmark", "gift_reminder_nagbar", b"gift_reminder_nagbar", "marketing_page_banner", b"marketing_page_banner", "mobile_bottom_sheet", b"mobile_bottom_sheet", "payment_modal_banner", b"payment_modal_banner", "placeholder", b"placeholder", "premium_tab", b"premium_tab", "premium_tab_tooltip", b"premium_tab_tooltip", "properties", b"properties"]  # noqa: Y015
    def HasField(self, field_name: _HasFieldArgType) -> _builtins.bool: ...
    _ClearFieldArgType: _TypeAlias = _typing.Literal["announcement_modal_variant_1", b"announcement_modal_variant_1", "billing_settings_nitro_gift_banner", b"billing_settings_nitro_gift_banner", "content_identifier", b"content_identifier", "gift_customization_banner", b"gift_customization_banner", "gift_icon", b"gift_icon", "gift_icon_coachmark", b"gift_icon_coachmark", "gift_plan_selection_card_banner", b"gift_plan_selection_card_banner", "gift_reminder_coachmark", b"gift_reminder_coachmark", "gift_reminder_nagbar", b"gift_reminder_nagbar", "marketing_page_banner", b"marketing_page_banner", "mobile_bottom_sheet", b"mobile_bottom_sheet", "payment_modal_banner", b"payment_modal_banner", "placeholder", b"placeholder", "premium_tab", b"premium_tab", "premium_tab_tooltip", b"premium_tab_tooltip", "properties", b"properties"]  # noqa: Y015
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...
    _WhichOneofReturnType_properties: _TypeAlias = _typing.Literal["placeholder", "announcement_modal_variant_1", "premium_tab", "marketing_page_banner", "payment_modal_banner", "mobile_bottom_sheet", "gift_icon", "gift_icon_coachmark", "gift_plan_selection_card_banner", "gift_customization_banner", "billing_settings_nitro_gift_banner", "gift_reminder_nagbar", "gift_reminder_coachmark", "premium_tab_tooltip"]  # noqa: Y015
    _WhichOneofArgType_properties: _TypeAlias = _typing.Literal["properties", b"properties"]  # noqa: Y015
    def WhichOneof(self, oneof_group: _WhichOneofArgType_properties) -> _WhichOneofReturnType_properties | None: ...

Global___PremiumMarketingComponentProperties: _TypeAlias = PremiumMarketingComponentProperties  # noqa: Y015
