# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: premium_marketing/v1/PremiumMarketingComponentProperties.proto
# Protobuf Python Version: 5.28.3
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    28,
    3,
    '',
    'premium_marketing/v1/PremiumMarketingComponentProperties.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n>premium_marketing/v1/PremiumMarketingComponentProperties.proto\x12#discord_protos.premium_marketing.v1\"\xaa=\n#PremiumMarketingComponentProperties\x12\x1a\n\x12\x63ontent_identifier\x18\x03 \x01(\t\x12\x15\n\x0bplaceholder\x18\x01 \x01(\tH\x00\x12\x94\x01\n\x1c\x61nnouncement_modal_variant_1\x18\x02 \x01(\x0b\x32l.discord_protos.premium_marketing.v1.PremiumMarketingComponentProperties.AnnouncementModalVariant1PropertiesH\x00\x12j\n\x0bpremium_tab\x18\x04 \x01(\x0b\x32S.discord_protos.premium_marketing.v1.PremiumMarketingComponentProperties.PremiumTabH\x00\x12}\n\x15marketing_page_banner\x18\x05 \x01(\x0b\x32\\.discord_protos.premium_marketing.v1.PremiumMarketingComponentProperties.MarketingPageBannerH\x00\x12{\n\x14payment_modal_banner\x18\x06 \x01(\x0b\x32[.discord_protos.premium_marketing.v1.PremiumMarketingComponentProperties.PaymentModalBannerH\x00\x12y\n\x13mobile_bottom_sheet\x18\x07 \x01(\x0b\x32Z.discord_protos.premium_marketing.v1.PremiumMarketingComponentProperties.MobileBottomSheetH\x00\x12\x66\n\tgift_icon\x18\x08 \x01(\x0b\x32Q.discord_protos.premium_marketing.v1.PremiumMarketingComponentProperties.GiftIconH\x00\x12y\n\x13gift_icon_coachmark\x18\t \x01(\x0b\x32Z.discord_protos.premium_marketing.v1.PremiumMarketingComponentProperties.GiftIconCoachmarkH\x00\x12\x8f\x01\n\x1fgift_plan_selection_card_banner\x18\n \x01(\x0b\x32\x64.discord_protos.premium_marketing.v1.PremiumMarketingComponentProperties.GiftPlanSelectionCardBannerH\x00\x12\x85\x01\n\x19gift_customization_banner\x18\x0b \x01(\x0b\x32`.discord_protos.premium_marketing.v1.PremiumMarketingComponentProperties.GiftCustomizationBannerH\x00\x12\x95\x01\n\"billing_settings_nitro_gift_banner\x18\x0c \x01(\x0b\x32g.discord_protos.premium_marketing.v1.PremiumMarketingComponentProperties.BillingSettingsNitroGiftBannerH\x00\x12{\n\x14gift_reminder_nagbar\x18\r \x01(\x0b\x32[.discord_protos.premium_marketing.v1.PremiumMarketingComponentProperties.GiftReminderNagbarH\x00\x12\x81\x01\n\x17gift_reminder_coachmark\x18\x0e \x01(\x0b\x32^.discord_protos.premium_marketing.v1.PremiumMarketingComponentProperties.GiftReminderCoachmarkH\x00\x12y\n\x13premium_tab_tooltip\x18\x0f \x01(\x0b\x32Z.discord_protos.premium_marketing.v1.PremiumMarketingComponentProperties.PremiumTabTooltipH\x00\x1am\n\x0b\x46\x65\x61tureCard\x12\x0e\n\x06header\x18\x01 \x01(\t\x12\x0c\n\x04pill\x18\x02 \x01(\t\x12\x0c\n\x04\x62ody\x18\x03 \x01(\t\x12\x12\n\nimage_link\x18\x04 \x01(\t\x12\x1e\n\x16image_link_light_theme\x18\x05 \x01(\t\x1a\x90\x01\n\x12SubscriptionButton\x12\x0c\n\x04\x63opy\x18\x01 \x01(\t\x12l\n\rbutton_action\x18\x02 \x01(\x0e\x32U.discord_protos.premium_marketing.v1.PremiumMarketingComponentProperties.ButtonAction\x1a<\n\x08Subtitle\x12\x0c\n\x04link\x18\x01 \x01(\t\x12\x0e\n\x06locale\x18\x02 \x01(\t\x12\x12\n\nis_default\x18\x03 \x01(\x08\x1a\xff\x05\n\x0fVariant1Storage\x12\xb5\x01\n)hero_art_localized_video_links_dark_theme\x18\x01 \x03(\x0b\x32\x81\x01.discord_protos.premium_marketing.v1.PremiumMarketingComponentProperties.Variant1Storage.HeroArtLocalizedVideoLinksDarkThemeEntry\x12\xb7\x01\n*hero_art_localized_video_links_light_theme\x18\x02 \x03(\x0b\x32\x82\x01.discord_protos.premium_marketing.v1.PremiumMarketingComponentProperties.Variant1Storage.HeroArtLocalizedVideoLinksLightThemeEntry\x12\x9e\x01\n\x1dhero_art_video_subtitle_links\x18\x03 \x03(\x0b\x32w.discord_protos.premium_marketing.v1.PremiumMarketingComponentProperties.Variant1Storage.HeroArtVideoSubtitleLinksEntry\x1aJ\n(HeroArtLocalizedVideoLinksDarkThemeEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1aK\n)HeroArtLocalizedVideoLinksLightThemeEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a@\n\x1eHeroArtVideoSubtitleLinksEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\x85\x06\n#AnnouncementModalVariant1Properties\x12\x0e\n\x06header\x18\x01 \x01(\t\x12\x11\n\tsubheader\x18\x02 \x01(\t\x12\x12\n\nvideo_link\x18\x03 \x01(\t\x12\x17\n\x0fhelp_article_id\x18\x04 \x01(\t\x12k\n\rfeature_cards\x18\x05 \x03(\x0b\x32T.discord_protos.premium_marketing.v1.PremiumMarketingComponentProperties.FeatureCard\x12p\n\x06\x62utton\x18\x06 \x01(\x0b\x32[.discord_protos.premium_marketing.v1.PremiumMarketingComponentProperties.SubscriptionButtonH\x00\x88\x01\x01\x12\x13\n\x0b\x64ismiss_key\x18\x07 \x01(\t\x12\'\n\x1fhero_art_video_link_light_theme\x18\x08 \x01(\t\x12&\n\x1ehero_art_image_link_dark_theme\x18\t \x01(\t\x12\'\n\x1fhero_art_image_link_light_theme\x18\n \x01(\t\x12\x16\n\x0emodal_top_pill\x18\x0b \x01(\t\x12\x0c\n\x04\x62ody\x18\x0c \x01(\t\x12s\n\x18hero_art_video_subtitles\x18\r \x03(\x0b\x32Q.discord_protos.premium_marketing.v1.PremiumMarketingComponentProperties.Subtitle\x12n\n\x07storage\x18\x0e \x01(\x0b\x32X.discord_protos.premium_marketing.v1.PremiumMarketingComponentProperties.Variant1StorageH\x01\x88\x01\x01\x42\t\n\x07_buttonB\n\n\x08_storage\x1a\x43\n\nPremiumTab\x12\x13\n\x0b\x62\x61\x64ge_label\x18\x01 \x01(\t\x12 \n\x18\x61\x63knowledged_badge_label\x18\x02 \x01(\t\x1a\x97\x01\n\x19MarketingPageBannerButton\x12\x0c\n\x04\x63opy\x18\x01 \x01(\t\x12l\n\rbutton_action\x18\x02 \x01(\x0e\x32U.discord_protos.premium_marketing.v1.PremiumMarketingComponentProperties.ButtonAction\x1a\xe3\x01\n\x13MarketingPageBanner\x12\x11\n\tasset_url\x18\x01 \x01(\t\x12\x0e\n\x06header\x18\x02 \x01(\t\x12\x0c\n\x04\x62ody\x18\x03 \x01(\t\x12\x17\n\x0fhelp_article_id\x18\x04 \x01(\t\x12w\n\x06\x62utton\x18\x05 \x01(\x0b\x32\x62.discord_protos.premium_marketing.v1.PremiumMarketingComponentProperties.MarketingPageBannerButtonH\x00\x88\x01\x01\x42\t\n\x07_button\x1a\x45\n\x12PaymentModalBanner\x12\x11\n\tasset_url\x18\x01 \x01(\t\x12\x0e\n\x06header\x18\x02 \x01(\t\x12\x0c\n\x04\x62ody\x18\x03 \x01(\t\x1a\x19\n\tCTAButton\x12\x0c\n\x04\x63opy\x18\x01 \x01(\t\x1a\xd1\x01\n\x11MobileBottomSheet\x12\x11\n\tasset_url\x18\x01 \x01(\t\x12\x0e\n\x06header\x18\x02 \x01(\t\x12\x0c\n\x04\x62ody\x18\x03 \x01(\t\x12\x17\n\x0fhelp_article_id\x18\x04 \x01(\t\x12g\n\x06\x62utton\x18\x05 \x01(\x0b\x32R.discord_protos.premium_marketing.v1.PremiumMarketingComponentProperties.CTAButtonH\x00\x88\x01\x01\x42\t\n\x07_button\x1a-\n\x08Gradient\x12\x12\n\x06\x63olors\x18\x01 \x03(\tB\x02\x10\x00\x12\r\n\x05\x61ngle\x18\x02 \x01(\x02\x1a\xdf\x01\n\x08GiftIcon\x12\x19\n\x11\x62ox_animation_url\x18\x01 \x01(\t\x12\x1d\n\x15trinket_animation_url\x18\x02 \x01(\t\x12\"\n\x1atrinket_glow_animation_url\x18\x03 \x01(\t\x12h\n\x08gradient\x18\x04 \x01(\x0b\x32Q.discord_protos.premium_marketing.v1.PremiumMarketingComponentProperties.GradientH\x00\x88\x01\x01\x42\x0b\n\t_gradient\x1ai\n\x0fThemeAwareAsset\x12\x11\n\tlight_url\x18\x01 \x01(\t\x12\x10\n\x08\x64\x61rk_url\x18\x02 \x01(\t\x12\x18\n\x10light_static_url\x18\x03 \x01(\t\x12\x17\n\x0f\x64\x61rk_static_url\x18\x04 \x01(\t\x1a\xbc\x01\n\x11GiftIconCoachmark\x12\x0e\n\x06header\x18\x01 \x01(\t\x12\x0c\n\x04\x62ody\x18\x02 \x01(\t\x12\x11\n\tasset_url\x18\x03 \x01(\t\x12l\n\x05\x61sset\x18\x04 \x01(\x0b\x32X.discord_protos.premium_marketing.v1.PremiumMarketingComponentProperties.ThemeAwareAssetH\x00\x88\x01\x01\x42\x08\n\x06_asset\x1a\xcf\x07\n\x1bGiftPlanSelectionCardBanner\x12\x0e\n\x06header\x18\x01 \x01(\t\x12\x14\n\x0c\x64\x65sktop_body\x18\x02 \x01(\t\x12\x13\n\x0bmobile_body\x18\x03 \x01(\t\x12s\n\x0c\x61vatar_asset\x18\x04 \x01(\x0b\x32X.discord_protos.premium_marketing.v1.PremiumMarketingComponentProperties.ThemeAwareAssetH\x00\x88\x01\x01\x12\x18\n\x10\x62\x61nner_asset_url\x18\x05 \x01(\t\x12\x1c\n\x14\x62\x61\x63kground_asset_url\x18\x06 \x01(\t\x12\x16\n\x0e\x63\x61rd_asset_url\x18\x07 \x01(\t\x12h\n\x08gradient\x18\x08 \x01(\x0b\x32Q.discord_protos.premium_marketing.v1.PremiumMarketingComponentProperties.GradientH\x01\x88\x01\x01\x12s\n\x0c\x62\x61nner_asset\x18\t \x01(\x0b\x32X.discord_protos.premium_marketing.v1.PremiumMarketingComponentProperties.ThemeAwareAssetH\x02\x88\x01\x01\x12w\n\x10\x62\x61\x63kground_asset\x18\n \x01(\x0b\x32X.discord_protos.premium_marketing.v1.PremiumMarketingComponentProperties.ThemeAwareAssetH\x03\x88\x01\x01\x12q\n\ncard_asset\x18\x0b \x01(\x0b\x32X.discord_protos.premium_marketing.v1.PremiumMarketingComponentProperties.ThemeAwareAssetH\x04\x88\x01\x01\x12z\n\x13mobile_banner_asset\x18\x0c \x01(\x0b\x32X.discord_protos.premium_marketing.v1.PremiumMarketingComponentProperties.ThemeAwareAssetH\x05\x88\x01\x01\x42\x0f\n\r_avatar_assetB\x0b\n\t_gradientB\x0f\n\r_banner_assetB\x13\n\x11_background_assetB\r\n\x0b_card_assetB\x16\n\x14_mobile_banner_asset\x1a\x8e\x05\n\x17GiftCustomizationBanner\x12\x11\n\tasset_url\x18\x01 \x01(\t\x12\x14\n\x0c\x64\x65sktop_body\x18\x02 \x01(\t\x12\x13\n\x0bmobile_body\x18\x03 \x01(\t\x12h\n\x08gradient\x18\x04 \x01(\x0b\x32Q.discord_protos.premium_marketing.v1.PremiumMarketingComponentProperties.GradientH\x00\x88\x01\x01\x12\x1c\n\x14\x62\x61\x63kground_asset_url\x18\x05 \x01(\t\x12l\n\x05\x61sset\x18\x06 \x01(\x0b\x32X.discord_protos.premium_marketing.v1.PremiumMarketingComponentProperties.ThemeAwareAssetH\x01\x88\x01\x01\x12w\n\x10\x62\x61\x63kground_asset\x18\x07 \x01(\x0b\x32X.discord_protos.premium_marketing.v1.PremiumMarketingComponentProperties.ThemeAwareAssetH\x02\x88\x01\x01\x12~\n\x17mobile_background_asset\x18\x08 \x01(\x0b\x32X.discord_protos.premium_marketing.v1.PremiumMarketingComponentProperties.ThemeAwareAssetH\x03\x88\x01\x01\x42\x0b\n\t_gradientB\x08\n\x06_assetB\x13\n\x11_background_assetB\x1a\n\x18_mobile_background_asset\x1a\x9a\x04\n\x1e\x42illingSettingsNitroGiftBanner\x12\x11\n\tasset_url\x18\x01 \x01(\t\x12\x0e\n\x06header\x18\x02 \x01(\t\x12\x0c\n\x04\x62ody\x18\x03 \x01(\t\x12\x1c\n\x14\x62\x61\x63kground_asset_url\x18\x04 \x01(\t\x12h\n\x08gradient\x18\x05 \x01(\x0b\x32Q.discord_protos.premium_marketing.v1.PremiumMarketingComponentProperties.GradientH\x00\x88\x01\x01\x12\x12\n\ntext_color\x18\x06 \x01(\t\x12\x18\n\x10\x61\x64\x64itional_terms\x18\x07 \x01(\t\x12l\n\x05\x61sset\x18\x08 \x01(\x0b\x32X.discord_protos.premium_marketing.v1.PremiumMarketingComponentProperties.ThemeAwareAssetH\x01\x88\x01\x01\x12w\n\x10\x62\x61\x63kground_asset\x18\t \x01(\x0b\x32X.discord_protos.premium_marketing.v1.PremiumMarketingComponentProperties.ThemeAwareAssetH\x02\x88\x01\x01\x42\x0b\n\t_gradientB\x08\n\x06_assetB\x13\n\x11_background_asset\x1a\"\n\x12GiftReminderNagbar\x12\x0c\n\x04\x62ody\x18\x01 \x01(\t\x1a\xc0\x01\n\x15GiftReminderCoachmark\x12\x0e\n\x06header\x18\x01 \x01(\t\x12\x0c\n\x04\x62ody\x18\x02 \x01(\t\x12\x11\n\tasset_url\x18\x03 \x01(\t\x12l\n\x05\x61sset\x18\x04 \x01(\x0b\x32X.discord_protos.premium_marketing.v1.PremiumMarketingComponentProperties.ThemeAwareAssetH\x00\x88\x01\x01\x42\x08\n\x06_asset\x1a\xa9\x01\n\x11PremiumTabTooltip\x12\x0e\n\x06header\x18\x01 \x01(\t\x12\x0c\n\x04\x62ody\x18\x02 \x01(\t\x12l\n\x05\x61sset\x18\x03 \x01(\x0b\x32X.discord_protos.premium_marketing.v1.PremiumMarketingComponentProperties.ThemeAwareAssetH\x00\x88\x01\x01\x42\x08\n\x06_asset\"\xa3\x02\n\x0c\x42uttonAction\x12\x1d\n\x19\x42UTTON_ACTION_UNSPECIFIED\x10\x00\x12%\n!BUTTON_ACTION_OPEN_MARKETING_PAGE\x10\x01\x12+\n\'BUTTON_ACTION_OPEN_TIER_2_PAYMENT_MODAL\x10\x02\x12+\n\'BUTTON_ACTION_OPEN_TIER_1_PAYMENT_MODAL\x10\x03\x12\x46\nBBUTTON_ACTION_OPEN_TIER_2_PAYMENT_MODAL_CUSTOM_CONFIRMATION_FOOTER\x10\x04\x12+\n\'BUTTON_ACTION_OPEN_PLAN_SELECTION_MODAL\x10\x05\x42\x0c\n\npropertiesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'premium_marketing.v1.PremiumMarketingComponentProperties_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_PREMIUMMARKETINGCOMPONENTPROPERTIES_VARIANT1STORAGE_HEROARTLOCALIZEDVIDEOLINKSDARKTHEMEENTRY']._loaded_options = None
  _globals['_PREMIUMMARKETINGCOMPONENTPROPERTIES_VARIANT1STORAGE_HEROARTLOCALIZEDVIDEOLINKSDARKTHEMEENTRY']._serialized_options = b'8\001'
  _globals['_PREMIUMMARKETINGCOMPONENTPROPERTIES_VARIANT1STORAGE_HEROARTLOCALIZEDVIDEOLINKSLIGHTTHEMEENTRY']._loaded_options = None
  _globals['_PREMIUMMARKETINGCOMPONENTPROPERTIES_VARIANT1STORAGE_HEROARTLOCALIZEDVIDEOLINKSLIGHTTHEMEENTRY']._serialized_options = b'8\001'
  _globals['_PREMIUMMARKETINGCOMPONENTPROPERTIES_VARIANT1STORAGE_HEROARTVIDEOSUBTITLELINKSENTRY']._loaded_options = None
  _globals['_PREMIUMMARKETINGCOMPONENTPROPERTIES_VARIANT1STORAGE_HEROARTVIDEOSUBTITLELINKSENTRY']._serialized_options = b'8\001'
  _globals['_PREMIUMMARKETINGCOMPONENTPROPERTIES_GRADIENT'].fields_by_name['colors']._loaded_options = None
  _globals['_PREMIUMMARKETINGCOMPONENTPROPERTIES_GRADIENT'].fields_by_name['colors']._serialized_options = b'\020\000'
  _globals['_PREMIUMMARKETINGCOMPONENTPROPERTIES']._serialized_start=104
  _globals['_PREMIUMMARKETINGCOMPONENTPROPERTIES']._serialized_end=7954
  _globals['_PREMIUMMARKETINGCOMPONENTPROPERTIES_FEATURECARD']._serialized_start=1869
  _globals['_PREMIUMMARKETINGCOMPONENTPROPERTIES_FEATURECARD']._serialized_end=1978
  _globals['_PREMIUMMARKETINGCOMPONENTPROPERTIES_SUBSCRIPTIONBUTTON']._serialized_start=1981
  _globals['_PREMIUMMARKETINGCOMPONENTPROPERTIES_SUBSCRIPTIONBUTTON']._serialized_end=2125
  _globals['_PREMIUMMARKETINGCOMPONENTPROPERTIES_SUBTITLE']._serialized_start=2127
  _globals['_PREMIUMMARKETINGCOMPONENTPROPERTIES_SUBTITLE']._serialized_end=2187
  _globals['_PREMIUMMARKETINGCOMPONENTPROPERTIES_VARIANT1STORAGE']._serialized_start=2190
  _globals['_PREMIUMMARKETINGCOMPONENTPROPERTIES_VARIANT1STORAGE']._serialized_end=2957
  _globals['_PREMIUMMARKETINGCOMPONENTPROPERTIES_VARIANT1STORAGE_HEROARTLOCALIZEDVIDEOLINKSDARKTHEMEENTRY']._serialized_start=2740
  _globals['_PREMIUMMARKETINGCOMPONENTPROPERTIES_VARIANT1STORAGE_HEROARTLOCALIZEDVIDEOLINKSDARKTHEMEENTRY']._serialized_end=2814
  _globals['_PREMIUMMARKETINGCOMPONENTPROPERTIES_VARIANT1STORAGE_HEROARTLOCALIZEDVIDEOLINKSLIGHTTHEMEENTRY']._serialized_start=2816
  _globals['_PREMIUMMARKETINGCOMPONENTPROPERTIES_VARIANT1STORAGE_HEROARTLOCALIZEDVIDEOLINKSLIGHTTHEMEENTRY']._serialized_end=2891
  _globals['_PREMIUMMARKETINGCOMPONENTPROPERTIES_VARIANT1STORAGE_HEROARTVIDEOSUBTITLELINKSENTRY']._serialized_start=2893
  _globals['_PREMIUMMARKETINGCOMPONENTPROPERTIES_VARIANT1STORAGE_HEROARTVIDEOSUBTITLELINKSENTRY']._serialized_end=2957
  _globals['_PREMIUMMARKETINGCOMPONENTPROPERTIES_ANNOUNCEMENTMODALVARIANT1PROPERTIES']._serialized_start=2960
  _globals['_PREMIUMMARKETINGCOMPONENTPROPERTIES_ANNOUNCEMENTMODALVARIANT1PROPERTIES']._serialized_end=3733
  _globals['_PREMIUMMARKETINGCOMPONENTPROPERTIES_PREMIUMTAB']._serialized_start=3735
  _globals['_PREMIUMMARKETINGCOMPONENTPROPERTIES_PREMIUMTAB']._serialized_end=3802
  _globals['_PREMIUMMARKETINGCOMPONENTPROPERTIES_MARKETINGPAGEBANNERBUTTON']._serialized_start=3805
  _globals['_PREMIUMMARKETINGCOMPONENTPROPERTIES_MARKETINGPAGEBANNERBUTTON']._serialized_end=3956
  _globals['_PREMIUMMARKETINGCOMPONENTPROPERTIES_MARKETINGPAGEBANNER']._serialized_start=3959
  _globals['_PREMIUMMARKETINGCOMPONENTPROPERTIES_MARKETINGPAGEBANNER']._serialized_end=4186
  _globals['_PREMIUMMARKETINGCOMPONENTPROPERTIES_PAYMENTMODALBANNER']._serialized_start=4188
  _globals['_PREMIUMMARKETINGCOMPONENTPROPERTIES_PAYMENTMODALBANNER']._serialized_end=4257
  _globals['_PREMIUMMARKETINGCOMPONENTPROPERTIES_CTABUTTON']._serialized_start=4259
  _globals['_PREMIUMMARKETINGCOMPONENTPROPERTIES_CTABUTTON']._serialized_end=4284
  _globals['_PREMIUMMARKETINGCOMPONENTPROPERTIES_MOBILEBOTTOMSHEET']._serialized_start=4287
  _globals['_PREMIUMMARKETINGCOMPONENTPROPERTIES_MOBILEBOTTOMSHEET']._serialized_end=4496
  _globals['_PREMIUMMARKETINGCOMPONENTPROPERTIES_GRADIENT']._serialized_start=4498
  _globals['_PREMIUMMARKETINGCOMPONENTPROPERTIES_GRADIENT']._serialized_end=4543
  _globals['_PREMIUMMARKETINGCOMPONENTPROPERTIES_GIFTICON']._serialized_start=4546
  _globals['_PREMIUMMARKETINGCOMPONENTPROPERTIES_GIFTICON']._serialized_end=4769
  _globals['_PREMIUMMARKETINGCOMPONENTPROPERTIES_THEMEAWAREASSET']._serialized_start=4771
  _globals['_PREMIUMMARKETINGCOMPONENTPROPERTIES_THEMEAWAREASSET']._serialized_end=4876
  _globals['_PREMIUMMARKETINGCOMPONENTPROPERTIES_GIFTICONCOACHMARK']._serialized_start=4879
  _globals['_PREMIUMMARKETINGCOMPONENTPROPERTIES_GIFTICONCOACHMARK']._serialized_end=5067
  _globals['_PREMIUMMARKETINGCOMPONENTPROPERTIES_GIFTPLANSELECTIONCARDBANNER']._serialized_start=5070
  _globals['_PREMIUMMARKETINGCOMPONENTPROPERTIES_GIFTPLANSELECTIONCARDBANNER']._serialized_end=6045
  _globals['_PREMIUMMARKETINGCOMPONENTPROPERTIES_GIFTCUSTOMIZATIONBANNER']._serialized_start=6048
  _globals['_PREMIUMMARKETINGCOMPONENTPROPERTIES_GIFTCUSTOMIZATIONBANNER']._serialized_end=6702
  _globals['_PREMIUMMARKETINGCOMPONENTPROPERTIES_BILLINGSETTINGSNITROGIFTBANNER']._serialized_start=6705
  _globals['_PREMIUMMARKETINGCOMPONENTPROPERTIES_BILLINGSETTINGSNITROGIFTBANNER']._serialized_end=7243
  _globals['_PREMIUMMARKETINGCOMPONENTPROPERTIES_GIFTREMINDERNAGBAR']._serialized_start=7245
  _globals['_PREMIUMMARKETINGCOMPONENTPROPERTIES_GIFTREMINDERNAGBAR']._serialized_end=7279
  _globals['_PREMIUMMARKETINGCOMPONENTPROPERTIES_GIFTREMINDERCOACHMARK']._serialized_start=7282
  _globals['_PREMIUMMARKETINGCOMPONENTPROPERTIES_GIFTREMINDERCOACHMARK']._serialized_end=7474
  _globals['_PREMIUMMARKETINGCOMPONENTPROPERTIES_PREMIUMTABTOOLTIP']._serialized_start=7477
  _globals['_PREMIUMMARKETINGCOMPONENTPROPERTIES_PREMIUMTABTOOLTIP']._serialized_end=7646
  _globals['_PREMIUMMARKETINGCOMPONENTPROPERTIES_BUTTONACTION']._serialized_start=7649
  _globals['_PREMIUMMARKETINGCOMPONENTPROPERTIES_BUTTONACTION']._serialized_end=7940
# @@protoc_insertion_point(module_scope)
